"""Doc of bioat.

"""
from __future__ import annotations
import sys

from pysam import __version__ as __pysam_version__
from pysamstats import __version__ as __pysamstats_version__

from bioat._version import version as __version__
from bioat._version import author as __author__
from bioat._version import email as __email__
from bioat._version import upgrade_date as __upgrade_date__
from bioat._logging import set_logging_level

__doc_format__ = "restructuredtext"
__name__ = "bioat"
